<?php

declare(strict_types=1);

/**
 * SPDX-FileCopyrightText: 2025 Sebastian Krupinski <krupinski01@gmail.com>
 * SPDX-License-Identifier: AGPL-3.0-only
 */

namespace JmapClient\Responses\Tasks;

use JmapClient\Responses\ResponseQuery;

class TaskQuery extends ResponseQuery
{
}
